@@ -18,6 +18,7 @@ use syn::{
 #[proc_macro_derive(DataSize, attributes(data_size))]
 pub fn derive_data_size(input: TokenStream) -> TokenStream {
     let input = parse_macro_input!(input as DeriveInput);
+    let input = remove_default_generic_values(input);
 
     match input.data {
         syn::Data::Struct(ds) => derive_for_struct(input.ident, input.generics, ds),
@@ -26,6 +27,17 @@ pub fn derive_data_size(input: TokenStream) -> TokenStream {
     }
 }
 
+fn remove_default_generic_values(mut input: DeriveInput) -> DeriveInput {
+    for param in input.generics.params.iter_mut() {
+        if let syn::GenericParam::Type(ty) = param {
+            ty.eq_token = None;
+            ty.default = None;
+        }
+    }
+
+    input
+}
+
 /// Returns whether any of the `generics` show up in `ty`.
 ///
 /// Used to determine whether or not a specific type needs to be listed in where clauses because it
